@@ -30,10 +30,10 @@ def plot_bode(w, Tjw):
     plt.figure("mag")
     plt.loglog(w, np.abs(Tjw))
     plt.ylabel("Modulus")
-    plt.xlabel("Amplification")
+    plt.xlabel("Angular Frequency (rad/s)")
 
     plt.figure("phase")
-    plt.semilogx(w, 180 * np.angle(Tjw) / np.pi)
+    plt.semilogx(w, np.angle(Tjw, deg=True))
     plt.ylabel("Argument")
     plt.xlabel("Angular Frequency (rad/s)")
 
